@@ -10,6 +10,7 @@ import torch.utils.data as torch_utils
 from torch.utils.data.dataset import Dataset
 from torch.utils.data.dataloader import DataLoader
 from ..engine import comm
+from .torch_tools import get_torch_version
 
 
 def build_dataloader(dataset: Dataset,
@@ -40,7 +41,11 @@ def build_dataloader(dataset: Dataset,
                                                              shuffle=shuffle)
         shuffle = False  # sampler option is mutually exclusive with shuffle
     # fix a bug: torch<=1.6 have no argument 'persistent_workers'
-    kwargs["persistent_workers"] = persistent_workers
+    try:
+        if get_torch_version() >= 1.7:
+            kwargs["persistent_workers"] = persistent_workers
+    except:
+        print("torch<=1.6 have no argument persistent_workers")
     dataloader = torch_utils.DataLoader(dataset,
                                         batch_size=batch_size,
                                         num_workers=num_workers,
@@ -65,7 +70,9 @@ def build_model_parallel(model: nn.Module,
     if comm.get_world_size() > 1:
         model = nn.parallel.DistributedDataParallel(model,
                                                     device_ids=[comm.get_device(device_ids)],
-                                                    output_device=comm.get_device(device_ids))
+                                                    output_device=comm.get_device(device_ids),
+                                                    **kwargs
+                                                    )
     else:
         # use DataParallel
         model = nn.DataParallel(model, device_ids=device_ids, output_device=comm.get_device(device_ids), **kwargs)
